package no.nordicsemi.android.nrftemp.adapter;

import android.content.Context;
import android.database.Cursor;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CursorAdapter;
import android.widget.TextView;

import com.nordic.android.nrftemp.R;

public class SensorAdapter extends CursorAdapter {
	/** Battery level that will cause the 'low battery' indicator to appear */
	private static final int CRITICAL_BATTERY = 10; // %

	private static final int COLUMN_NAME = 2;
	private static final int COLUMN_TEMP = 4;
	private static final int COLUMN_BATTERY = 5;
	private static final int COLUMN_RECENT = 7;

	public SensorAdapter(Context context, Cursor c) {
		super(context, c, false);
	}

	@Override
	public View newView(Context context, Cursor cursor, ViewGroup parent) {
		final View view = LayoutInflater.from(context).inflate(R.layout.sensors_list_row, parent, false);

		final ViewHolder holder = new ViewHolder();
		holder.mName = (TextView) view.findViewById(R.id.name);
		holder.mStatus = (TextView) view.findViewById(R.id.status);
		holder.mTemp = (TextView) view.findViewById(R.id.temp);
		holder.mBattery = view.findViewById(R.id.battery);
		view.setTag(holder);

		return view;
	}

	@Override
	public void bindView(View view, Context context, Cursor cursor) {
		final ViewHolder holder = (ViewHolder) view.getTag();
		holder.mName.setText(cursor.getString(COLUMN_NAME));

		if (1 == cursor.getInt(COLUMN_RECENT)) {
			holder.mStatus.setText(R.string.status_updated);
			holder.mStatus.setTextColor(Color.BLACK);
		} else {
			holder.mStatus.setText(R.string.status_not_found);
			holder.mStatus.setTextColor(Color.RED);
		}
		holder.mTemp.setText(context.getResources().getString(R.string.temp, cursor.getFloat(COLUMN_TEMP)));

		final int battery = cursor.getInt(COLUMN_BATTERY);
		holder.mBattery.setVisibility(battery <= CRITICAL_BATTERY ? View.VISIBLE : View.INVISIBLE);
	}

	/** Temporary holder for views. Speeds up fast scrolling process */
	private class ViewHolder {
		private TextView mName;
		private TextView mStatus;
		private TextView mTemp;
		private View mBattery;
	}
}
